import React, { useState, useEffect } from 'react';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { Form, Pagination, Card, Button, Icon, Tooltip, message, notification, Modal, Table, Select, Input, DatePicker } from 'antd';
import router from 'umi/router';
import moment from 'moment';
import className from 'classnames';
import Cell from '../../components/Cell';
import styles from './style.less';
import { fetch, apis } from '../../utils/request';
import request from '../../utils/request';
import AuthButton from '@/components/AuthButton';

const { MonthPicker, RangePicker, WeekPicker } = DatePicker;

function header(props) {
    // 获取初始化数据
    const [data, setData] = useState({})
    const [demandIdList, setDemandIdList] = useState([])

    useEffect(() => {
        getList({ pageNum: 1, pageSize: 10 });
    }, [])

    // 查询列表
    const getList = (params) => {
        request({ ...apis.sample.list, params: { ...params } }).then((data) => {
            console.log(data)
            setData(data)
        })
    }


    // 提交事件
    const handleSubmit = (e, props) => {
        e.preventDefault();
        props.form.validateFields((err, values) => {
            if (!err) {
                let { createDate, ...submitValue } = values
                if (null != createDate && createDate.length > 0) {
                    const [startCreateDate, endCreateDate] = createDate
                    submitValue.startCreateDate = moment(startCreateDate).format('YYYY-MM-DD');
                    submitValue.endCreateDate = moment(endCreateDate).format('YYYY-MM-DD');
                } else {
                    submitValue.startCreateDate = null
                    submitValue.endCreateDate = null
                }
                getList({ pageNum: 1, pageSize: 10, ...submitValue })
            }
        });
    }

    const changePageNum = (pageNumber) => {
        let { createDate, ...submitValue } = props.form.getFieldsValue()
        if (null != createDate && createDate.length > 0) {
            const [startCreateDate, endCreateDate] = createDate
            submitValue.startCreateDate = moment(startCreateDate).format('YYYY-MM-DD');
            submitValue.endCreateDate = moment(endCreateDate).format('YYYY-MM-DD');
        } else {
            submitValue.startCreateDate = null
            submitValue.endCreateDate = null
        }
        getList({ pageNum: pageNumber, pageSize: 10, ...submitValue })
    }

    /**
     *
     *
     * @param {*} props
     * @returns
     */
    const columns = [
        {
            title: '账户',
            dataIndex: 'sampleName',
            key: 'sampleName',
            align: 'center',
            render: (x, row) => (
                <>
                    <span style={{ color: '#FF925C', cursor: 'pointer', marginRight: '16px' }} onClick={() => toDeatil()} >
                        {row.sampleName}
                    </span>
                </>
            ),
        },
        {
            title: '总充值金额',
            dataIndex: 'orgName',
            key: 'orgName',
            align: 'center',
        },
        {
            title: '已消费金额',
            dataIndex: 'orderer',
            key: 'orderer',
            align: 'center',
        },
        {
            title: '已退款金额',
            dataIndex: 'orderer',
            key: 'orderer',
            align: 'center',
        },
        {
            title: '余额',
            dataIndex: 'orderer',
            key: 'orderer',
            align: 'center',
        },
        {
            title: '操作',
            dataIndex: 'createDate',
            key: 'createDate',
            align: 'center',
            width: '120px',
            render: (x, row) => (
                <>
                    <span style={{ color: '#FF925C', cursor: 'pointer', marginRight: '16px' }} >
                        充值
                    </span>
                    <span style={{ color: '#FF925C', cursor: 'pointer' }} >
                        退款
                    </span>
                </>
            ),
        },

    ];
    function handleReset() {
        props.form.resetFields();
        getList({ pageNum: 1, pageSize: 10 })
    }

    const toDeatil = () => {
        router.push({
            pathname: '/fundManagement/AccountDetail',
        });
    }

    const { getFieldDecorator } = props.form
    return (

        <>
            <Form layout="inline" onSubmit={e => handleSubmit(e, props)} style={{ marginBottom: '16px' }}>
                <Form.Item>
                    {getFieldDecorator('orgName')(
                        <Input
                            prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
                            placeholder="输入小程序名"
                        />,
                    )}
                </Form.Item>

                <Form.Item>
                    <Button type="primary" htmlType="submit" className={styles.searchBtn}>
                        搜索
                    </Button>
                    <Button style={{ marginLeft: 8 }} onClick={handleReset}>
                        重置
                    </Button>
                </Form.Item>
            </Form>
            <Table rowKey="newsType" dataSource={data.records} columns={columns} pagination={false} />
            <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
                <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={changePageNum} current={data.current} />
            </div>
        </>
    )
}
const WrappedHeader = Form.create({ name: 'header' })(header);

export default WrappedHeader